
# import requests
# from langchain_core.prompts import PromptTemplate
# from kynex.llm.base import LLMBase
#
# class OllamaLLMWrapper(LLMBase):
#     def __init__(self, model_name: str, host: str, security_token: str = None):
#         self.model_name = model_name
#         self.host = host
#         self.security_token = security_token  # kept for future if needed, but unused
#         self.api_url = f"{self.host}/api/generate"
#         print(f"🔹 [OllamaLLMWrapper] Initialized with model: {self.model_name} at {self.host}")
#
#     def get_data(self, prompt: str) -> str:
#         try:
#             print(f"🔹 [OllamaLLMWrapper] Prompt:\n{prompt}")
#             template = PromptTemplate.from_template("{prompt}")
#             formatted_prompt = template.format(prompt=prompt)
#
#             payload = {
#                 "model": self.model_name,
#                 "prompt": formatted_prompt,
#                 "stream": False
#             }
#
#             # ✅ No API key required now — send freely to any host
#             response = requests.post(self.api_url, json=payload)
#             response.raise_for_status()
#             return "[Ollama] " + response.json().get("response", "[No response]")
#         except Exception as e:
#             return f"[Ollama ERROR]: {str(e)}"

# import requests
# from langchain_core.prompts import PromptTemplate
# from kynex.llm.base import LLMBase
#
# class OllamaLLMWrapper(LLMBase):
#     def __init__(self, model_name: str, host: str):
#         self.model_name = model_name
#         self.host = host
#         self.api_url = f"{self.host}/api/generate"
#         print(f"🔹 [OllamaLLMWrapper] Initialized with model: {self.model_name} at {self.host}")
#
#     def get_data(self, prompt: str) -> str:
#         try:
#             print(f"🔹 [OllamaLLMWrapper] Prompt:\n{prompt}")
#             template = PromptTemplate.from_template("{prompt}")
#             formatted_prompt = template.format(prompt=prompt)
#
#             payload = {
#                 "model": self.model_name,
#                 "prompt": formatted_prompt,
#                 "stream": False
#             }
#
#             response = requests.post(self.api_url, json=payload)
#             response.raise_for_status()
#             return "[Ollama] " + response.json().get("response", "[No response]")
#         except Exception as e:
#             return f"[Ollama ERROR]: {str(e)}"


from langchain_ollama import OllamaLLM
from langchain_core.prompts import PromptTemplate
from kynex.llm.base import LLMBase

class OllamaLLMWrapper(LLMBase):
    def __init__(self, model_name: str, host: str):
        self.model_name = model_name
        self.host = host  # Used for base_url
        #  Initialize LangChain OllamaLLM
        self.llm = OllamaLLM(model=self.model_name, base_url=self.host)
        print(f"🔹 [OllamaLLMWrapper] Initialized with model: {self.model_name} at {self.host}")

    def get_data(self, prompt: str) -> str:
        try:
            print(f"🔹 [OllamaLLMWrapper] Prompt:\n{prompt}")
            template = PromptTemplate.from_template("{prompt}")
            formatted_prompt = template.format(prompt=prompt)

            #  Use LangChain OllamaLLM invoke method
            response = self.llm.invoke(formatted_prompt)
            return "[Ollama] " + response
        except Exception as e:
            return f"[Ollama ERROR]: {str(e)}"



# import os
# import configparser
# from kynex.llm.gemini.gemini import GeminiLLM
# from kynex.llm.groq.groq import GroqLLM
# from kynex.llm.ollama.ollama import OllamaLLMWrapper as OllamaLLM
#
# class LLMConnector:
#     def __init__(self, api_key: str, model_name: str, llm_type: str = "gemini", host: str = None):
#         self.api_key = api_key
#         self.model_name = model_name
#         self.llm_type = llm_type.lower() if llm_type else "gemini"
#         self.host = host or self.load_default_host()  # Load default Ollama host if not given
#
#     def load_default_host(self):
#         """Loads default Ollama host if not explicitly provided (optional config fallback)."""
#         config = configparser.ConfigParser()
#         config.read(os.path.abspath("resources/kynex.properties"))
#         return config.get("DEFAULT", "ollama_host", fallback="http://localhost:11434")
#
#     def get_llm_instance(self):
#         print(f"🔍 Selected LLM: {self.llm_type} | Model: {self.model_name}")
#
#         if self.llm_type == "gemini":
#             return GeminiLLM(api_key=self.api_key, model_name=self.model_name)
#         elif self.llm_type == "groq":
#             return GroqLLM(api_key=self.api_key, model_name=self.model_name)
#         elif self.llm_type == "ollama":
#             return OllamaLLM(
#                 model_name=self.model_name,
#                 host=self.host,
#                 security_token=self.api_key  # Secure Token Required
#             )
#         else:
#             raise ValueError(f"Unsupported LLM type: {self.llm_type}")
#
#     def getLLMData(self, prompt: str) -> str:
#         llm = self.get_llm_instance()
#         return llm.get_data(prompt)

#
# from kynex.llm.gemini.gemini import GeminiLLM
# from kynex.llm.groq.groq import GroqLLM
# from kynex.llm.ollama.ollama import OllamaLLMWrapper as OllamaLLM
#
# class LLMConnector:
#     def __init__(self, model_name: str, llm_type: str, host: str = None):
#         self.model_name = model_name
#         self.llm_type = llm_type.lower()
#         self.host = host  # Host required for Ollama
#
#     def get_llm_instance(self):
#         print(f"🔍 Selected LLM: {self.llm_type} | Model: {self.model_name}")
#
#         if self.llm_type == "gemini":
#             return GeminiLLM(model_name=self.model_name)
#         elif self.llm_type == "groq":
#             return GroqLLM(model_name=self.model_name)
#         elif self.llm_type == "ollama":
#             if not self.host:
#                 raise ValueError("Host is required for Ollama LLM.")
#             return OllamaLLM(model_name=self.model_name, host=self.host)
#         else:
#             raise ValueError(f"Unsupported LLM type: {self.llm_type}")
#
#     def getLLMData(self, prompt: str) -> str:
#         llm = self.get_llm_instance()
#         return llm.get_data(prompt)


from kynex.llm.gemini.GeminiLLMWrapper import GeminiLLMWrapper
from kynex.llm.groq.GroqLLMWrapper import GroqLLMWrapper
from kynex.llm.ollama.OllamaLLMWrapper import OllamaLLMWrapper

class LLMConnectorHelper:
    def __init__(self, model_name: str, llm_type: str, api_key: str = None, host: str = None):
        self.model_name = model_name
        self.llm_type = llm_type.lower()
        self.api_key = api_key
        self.host = host

    def get_llm_instance(self):
        print(f"🔍 Selected LLM: {self.llm_type} | Model: {self.model_name}")

        if self.llm_type == "gemini":
            return GeminiLLMWrapper(api_key=self.api_key, model_name=self.model_name)
        elif self.llm_type == "groq":
            return GroqLLMWrapper(api_key=self.api_key, model_name=self.model_name)
        elif self.llm_type == "ollama":
            if not self.host:
                raise ValueError("Host is required for Ollama LLM.")
            return OllamaLLMWrapper(model_name=self.model_name, host=self.host)
        else:
            raise ValueError(f"Unsupported LLM type: {self.llm_type}")

    def getLLMData(self, prompt: str) -> str:
        llm = self.get_llm_instance()
        return llm.get_data(prompt)



# import os
# import google.generativeai as genai
# from langchain_core.prompts import PromptTemplate
# from kynex.llm.base import LLMBase
#
# class GeminiLLM(LLMBase):
#     def __init__(self):
#         genai.configure(api_key=os.getenv("GEMINI_API_KEY"))
#
#     def get_data(self, prompt: str, model_name: str = "gemini-1.5-flash") -> str:  # ✅ FIXED
#         try:
#             model = genai.GenerativeModel(model_name)
#             template = PromptTemplate.from_template("{prompt}")
#             formatted_prompt = template.format(prompt=prompt)
#
#             response = model.generate_content(formatted_prompt)
#             return response.text
#         except Exception as e:
#             return f"[Gemini ERROR]: {str(e)}"


# import google.generativeai as genai
# from langchain_core.prompts import PromptTemplate
# from kynex.llm.base import LLMBase
#
# class GeminiLLM(LLMBase):
#     def __init__(self, api_key: str, model_name: str = "gemini-1.5-flash"):
#         genai.configure(api_key=api_key)
#         self.model = genai.GenerativeModel(model_name)
#     def get_data(self, prompt: str) -> str:
#         try:
#             template = PromptTemplate.from_template("{prompt}")
#             formatted_prompt = template.format(prompt=prompt)
#             response = self.model.generate_content(formatted_prompt)
#             print(response)
#             return response.text
#         except Exception as e:
#             return f"[Gemini ERROR]: {str(e)}"


import google.generativeai as genai
from langchain_core.prompts import PromptTemplate
from kynex.llm.base import LLMBase

class GeminiLLMWrapper(LLMBase):
    def __init__(self, api_key: str, model_name: str = "gemini-1.5-flash"):
        genai.configure(api_key=api_key)
        self.model = genai.GenerativeModel(model_name)
        print(f"🔹 [GeminiLLM] Initialized with model: {model_name}")

    def get_data(self, prompt: str) -> str:
        try:
            print(f"🔹 [GeminiLLM] Generating response for prompt:\n{prompt}")
            template = PromptTemplate.from_template("{prompt}")
            formatted_prompt = template.format(prompt=prompt)

            response = self.model.generate_content(formatted_prompt)
            return "[Gemini] " + response.text

        except Exception as e:
            return f"[Gemini ERROR]: {str(e)}"



#
# from kynex.llm_connector import LLMConnector
#
#
# class Kynexa:
#     LLM_GEMINI = "gemini"
#     LLM_GROQ = "groq"
#     LLM_OLLAMA = "ollama"
#     #@staticmethod
#     # def get_llm_response(prompt: str, model_name: str, api_key: str, llm_type: str = None) -> str:
#     #
#     #     if llm_type is None:
#     #         llm_type = Kynexa.LLM_GEMINI
#     #     connector = LLMConnector(api_key=api_key, model_name=model_name, llm_type=llm_type)
#     #     return connector.getLLMData(prompt)
#     @staticmethod
#     def get_llm_response(prompt: str, model_name: str, api_key: str, llm_type: str = None, host: str = None) -> str:
#         if llm_type is None:
#             llm_type = Kynexa.LLM_GEMINI
#         connector = LLMConnector(api_key=api_key, model_name=model_name, llm_type=llm_type, host=host)
#         return connector.getLLMData(prompt)


from kynex.util.LLMConnectorHelper import LLMConnectorHelper

class LLMConnector:
    LLM_GEMINI = "gemini"
    LLM_GROQ = "groq"
    LLM_OLLAMA = "ollama"

    @staticmethod
    def get_llm_response(prompt: str, model_name: str, llm_type: str = None, api_key: str = None,
                         host: str = None) -> str:
        if llm_type is None:
            llm_type = LLMConnector.LLM_OLLAMA  # Default to ollama if not given
        connector = LLMConnectorHelper(model_name=model_name, llm_type=llm_type, api_key=api_key, host=host)
        return connector.getLLMData(prompt)



from groq import Groq
from langchain_core.prompts import PromptTemplate
from kynex.llm.base import LLMBase

class GroqLLMWrapper(LLMBase):
    def __init__(self, api_key: str, model_name: str):
        self.client = Groq(api_key=api_key)
        self.model_name = model_name

    def get_data(self, prompt: str) -> str:
        try:
            # Optional: format prompt using LangChain template
            template = PromptTemplate.from_template("{prompt}")
            formatted_prompt = template.format(prompt=prompt)

            response = self.client.chat.completions.create(
                model=self.model_name,
                messages=[{"role": "user", "content": formatted_prompt}],
                temperature=0.7
            )
            print(response)

            return response.choices[0].message.content.strip()
        except Exception as e:
            return f"[Groq ERROR]: {str(e)}"
